<?php

declare(strict_types=1);

namespace App\Controller;

use App\Service\ConfigurationService;
use App\Service\DrinkTypeService;
use App\Service\InventoryService;
use Psr\Http\Message\ResponseInterface as Response;
use Slim\Views\Twig;

class DashboardController
{
    public function __construct(
        private readonly Twig $view,
        private readonly InventoryService $inventoryService,
        private readonly DrinkTypeService $drinkTypeService,
        private readonly ConfigurationService $configService
    ) {}

    public function index(Response $response): Response
    {
        // Get low stock items for the low-stock-alerts component
        $lowStockItems = $this->inventoryService->getLowStockDrinkTypes();

        // Get all drink types for the quick-update-form component
        $drinkTypes = $this->drinkTypeService->getAllDrinkTypes();

        // Get configuration settings
        $showLowStockAlerts = (bool) $this->configService->getConfigValue('show_low_stock_alerts', '1');
        $showQuickUpdateForm = (bool) $this->configService->getConfigValue('show_quick_update_form', '1');

        return $this->view->render($response, 'dashboard/index.twig', [
            'lowStockItems' => $lowStockItems,
            'drinkTypes' => $drinkTypes,
            'showLowStockAlerts' => $showLowStockAlerts,
            'showQuickUpdateForm' => $showQuickUpdateForm
        ]);
    }
}
