<?php

declare(strict_types=1);

use App\Middleware\ErrorHandlerMiddleware;
use Monolog\Logger;
use Slim\App;
use Slim\Views\Twig;
use DI\Bridge\Slim\Bridge;

return (function (): App {
    // Create container
    $container = (require __DIR__ . '/../config/container.php')();
    /** @var \App\Settings $settings */
    $settings = $container->get(\App\Settings::class);

    // create cache dirs
    foreach (['twig', 'doctrine/proxy'] as $dir) {
        if (!is_dir($settings->cacheDir . '/' . $dir)) {
            mkdir($settings->cacheDir . '/' . $dir, 0777, true);
        }
    }

    // Create app with container
    $app = Bridge::create($container);

    // Add middleware
    $app->add(new ErrorHandlerMiddleware(
        $container->get(Logger::class),
        $container->get(Twig::class),
        true // Set to false in production
    ));

    // Add routes
    (require __DIR__ . '/routes.php')($app);

    return $app;
})();
