<?php

declare(strict_types=1);

use App\Controller\DashboardController;
use App\Controller\DrinkTypeController;
use App\Controller\InventoryController;
use App\Controller\OrderController;
use App\Controller\SettingsController;
use Slim\App;

return function (App $app): void {
    // Dashboard routes
    $app->get('/', [DashboardController::class, 'index']);

    // Drink Type routes
    $app->get('/drink-types', [DrinkTypeController::class, 'index']);
    $app->get('/drink-types/create', [DrinkTypeController::class, 'create']);
    $app->post('/drink-types', [DrinkTypeController::class, 'store']);
    $app->get('/drink-types/{id:[0-9]+}', [DrinkTypeController::class, 'show']);
    $app->get('/drink-types/{id:[0-9]+}/edit', [DrinkTypeController::class, 'edit']);
    $app->post('/drink-types/{id:[0-9]+}', [DrinkTypeController::class, 'update']);
    $app->post('/drink-types/{id:[0-9]+}/delete', [DrinkTypeController::class, 'delete']);

    // Inventory routes
    $app->get('/inventory', [InventoryController::class, 'index']);
    $app->get('/inventory/update', [InventoryController::class, 'showUpdateForm']);
    $app->post('/inventory/update', [InventoryController::class, 'update']);
    $app->get('/inventory/history', [InventoryController::class, 'history']);
    $app->get('/inventory/history/{id:[0-9]+}', [InventoryController::class, 'history']);
    $app->get('/inventory/low-stock', [InventoryController::class, 'lowStock']);

    // Order routes
    $app->get('/orders', [OrderController::class, 'index']);
    $app->get('/orders/create', [OrderController::class, 'create']);
    $app->post('/orders', [OrderController::class, 'store']);
    $app->get('/orders/create-from-stock', [OrderController::class, 'createFromStock']);
    $app->get('/orders/{id:[0-9]+}', [OrderController::class, 'show']);
    $app->post('/orders/{id:[0-9]+}/status', [OrderController::class, 'updateStatus']);
    $app->post('/orders/{id:[0-9]+}/items', [OrderController::class, 'addItem']);
    $app->post('/orders/{id:[0-9]+}/items/{itemId:[0-9]+}/remove', [OrderController::class, 'removeItem']);
    $app->post('/orders/{id:[0-9]+}/delete', [OrderController::class, 'delete']);

    // Settings routes
    $app->get('/settings', [SettingsController::class, 'index']);
    $app->post('/settings', [SettingsController::class, 'update']);
    $app->post('/settings/reset', [SettingsController::class, 'resetToDefaults']);
};
